<?php
/**
 * @since   2.0.0
 *
 * @param          $label
 * @param          $selector
 * @param          $default
 * @param string[] $properties
 *
 * @return array
 */
function sm_get_color_select_darker_config( $label, $selector, $default, $properties = [ 'color' ] ) {
	return sm_get_color_select_dark_config( $label, $selector, $default, $properties, true );
}

/**
 * @since   2.0.0
 *
 * @param          $label
 * @param          $selector
 * @param          $default
 * @param string[] $properties
 * @param false    $isDarker
 *
 * @return array
 */
function sm_get_color_select_dark_config( $label, $selector, $default, $properties = [ 'color' ], $isDarker = false ) {

	$callback = 'sm_color_select_dark_cb';
	$choices  = [
		'background' => esc_html__( 'Background', 'style-manager' ),
		'dark'       => esc_html__( 'Dark', 'style-manager' ),
		'accent'     => esc_html__( 'Accent', 'style-manager' ),
	];

	if ( $isDarker ) {
		$callback = 'sm_color_select_darker_cb';
		$choices  = [
			'background' => esc_html__( 'Background', 'style-manager' ),
			'darker'     => esc_html__( 'Dark', 'style-manager' ),
			'accent'     => esc_html__( 'Accent', 'style-manager' ),
		];
	}

	$css = [];

	if ( ! is_array( $properties ) ) {
		$properties = [ $properties ];
	}

	foreach ( $properties as $property ) {
		$css[] = [
			'property'        => $property,
			'selector'        => $selector,
			'callback_filter' => $callback,
		];
	}

	return [
		'type'    => 'select_color',
		'label'   => $label,
		'live'    => true,
		'default' => $default,
		'css'     => $css,
		'choices' => $choices,
	];
}

/**
 * @since   2.0.0
 *
 * @param string $value
 * @param string $selector
 * @param string $property
 *
 * @return string
 */
function sm_color_select_dark_cb( $value, $selector, $property ) {
	$value = (string) $value;
	$selector = (string) $selector;
	$property = (string) $property;
	return $selector . ' { ' . $property . ': var(--sm-current-' . $value . '-color); }' . PHP_EOL;
}

/**
 * @since   2.0.0
 *
 * @param string $value
 * @param string $selector
 * @param string $property
 *
 * @return string
 */
function sm_color_select_darker_cb( $value, $selector, $property ) {
	$value = (string) $value;
	$selector = (string) $selector;
	$property = (string) $property;
	return $selector . ' { ' . $property . ': var(--sm-current-' . $value . '-color); }' . PHP_EOL;
}

/**
 * @since   2.0.0
 *
 * @param          $label
 * @param          $selector
 * @param          $default
 * @param string[] $properties
 *
 * @return array
 */
function sm_get_color_switch_darker_config( $label, $selector, $default, $coloration = 2, $properties = [ 'color' ] ) {
	return sm_get_color_switch_dark_config( $label, $selector, $default, $coloration, $properties, true );
}

/**
 * @since   2.0.0
 *
 * @param          $label
 * @param          $selector
 * @param          $default
 * @param string[] $properties
 * @param false    $isDarker
 *
 * @return array
 */
function sm_get_color_switch_dark_config( $label, $selector, $default, $coloration = 2, $properties = [ 'color' ], $isDarker = false ) {

	$css      = [];
	$callback = 'sm_color_switch_dark_cb';

	if ( $isDarker ) {
		$callback = 'sm_color_switch_darker_cb';
	}

	if ( ! is_array( $properties ) ) {
		$properties = [ $properties ];
	}

	foreach ( $properties as $property ) {
		$css[] = [
			'property'        => $property,
			'selector'        => $selector,
			'callback_filter' => $callback,
		];
	}

	return [
		'type'       => 'sm_toggle',
		'label'      => $label,
		'live'       => true,
		'default'    => $default,
		'css'        => $css,
		'coloration' => $coloration,
	];
}

/**
 * @since   2.0.0
 *
 * @param bool $value
 * @param string $selector
 * @param string $property
 *
 * @return string
 */
function sm_color_switch_dark_cb( $value, $selector, $property ) {
	$value = (bool) $value;
	$selector = (string) $selector;
	$property = (string) $property;
	$color = 'fg1';

	if ( $value === true ) {
		$color = 'accent';
	}

	return $selector . ' {' . $property . ': var(--sm-current-' . $color . '-color); }' . PHP_EOL;
}

/**
 * @since   2.0.0
 *
 * @param bool $value
 * @param string $selector
 * @param string $property
 *
 * @return string
 */
function sm_color_switch_darker_cb( $value, $selector, $property ) {
	$value = (bool) $value;
	$selector = (string) $selector;
	$property = (string) $property;
	$color = 'fg2';

	if ( $value === true ) {
		$color = 'accent';
	}

	return $selector . ' {' . $property . ': var(--sm-current-' . $color . '-color); }' . PHP_EOL;
}

/**
 * @since   2.0.0
 *
 * @param string $value
 *
 * @return string
 */
function sm_advanced_palette_output_cb( $value ) {
	$value = (string) $value;
	return '';
}

/**
 * @since   2.0.0
 *
 * @param string $value
 *
 * @return string
 */
function sm_variation_range_cb( $value ) {
	$value = (string) $value;
	return '';
}

/**
 * @since   2.0.0
 *
 * @param string $value
 *
 * @return string
 */
function sm_get_palette_output_from_color_config( $value ) {
	$output = '';

	$palettes = json_decode( $value );

	if ( empty( $palettes ) ) {
		$palettes = get_fallback_palettes();
	}

	$output .= palettes_output( $palettes );

	return $output;
}

/**
 * @since   2.0.0
 *
 * @param array $palettes
 *
 * @return string
 */
function palettes_output( array $palettes ) {
	$output = '';
	$variation = intval( get_option( 'sm_site_color_variation', 1 ) );

	foreach ( $palettes as $palette ) {
		$sourceIndex = $palette->sourceIndex;

		$output .= 'html { ' . PHP_EOL;
		$output .= get_initial_color_variables( $palette );
		$output .= get_variables_css( $palette, $variation - 1 );
		$output .= get_variables_css( $palette, $sourceIndex, false, true );
		$output .= '}' . PHP_EOL;

		$output .= '.is-dark { ' . PHP_EOL;
		$output .= get_variables_css( $palette, $variation - 1, true );
		$output .= get_variables_css( $palette, $sourceIndex, true, true );
		$output .= '}' . PHP_EOL;

		$output .= '.sm-palette-' . $palette->id . ' { ' . PHP_EOL;
		$output .= get_apply_palette_variables( $palette->id );
		$output .= '}' . PHP_EOL;

		$output .= '.sm-palette-' . $palette->id . '.sm-palette--shifted { ' . PHP_EOL;
		$output .= get_apply_palette_variables( $palette->id, '-shifted' );
		$output .= '}' . PHP_EOL;
	}

	return $output;
}

function get_apply_palette_variables( $id, $suffix = '' ) {
	$output = '';

	for ( $i = 1; $i <= 12; $i++ ) {
		$output .= '--sm-bg-color-' . $i . ': var(--sm-color-palette-' . $id . '-bg-color-' . $i . $suffix . ');' . PHP_EOL;
		$output .= '--sm-accent-color-' . $i . ': var(--sm-color-palette-' . $id . '-accent-color-' . $i . $suffix . ');' . PHP_EOL;
		$output .= '--sm-fg1-color-' . $i . ': var(--sm-color-palette-' . $id . '-fg1-color-' . $i . $suffix . ');' . PHP_EOL;
		$output .= '--sm-fg2-color-' . $i . ': var(--sm-color-palette-' . $id . '-fg2-color-' . $i . $suffix . ');' . PHP_EOL;
	}

	return $output;
}

/**
 * @since   2.0.0
 *
 * @param object $palette
 *
 * @return string
 */
function get_initial_color_variables( $palette ) {
	$colors = $palette->colors;
	$textColors = $palette->textColors;
	$id = $palette->id;
	$prefix = '--sm-color-palette-';

	$output = '';

	foreach ( $colors as $index => $color ) {
		$output .= $prefix . $id . '-color-' . ( $index + 1 ) . ': ' . $color->value . ';' . PHP_EOL;
	}

	foreach ( $textColors as $index => $color ) {
		$output .= $prefix . $id . '-text-color-' . ( $index + 1 ) . ': ' . $color->value . ';' . PHP_EOL;
	}

	return $output;
}

/**
 * @since   2.0.0
 *
 * @param object $palette
 * @param int    $offset
 * @param bool   $isDark
 * @param bool   $isShifted
 *
 * @return string
 */
function get_variables_css( $palette, $offset = 0, $isDark = false, $isShifted = false ) {
	$offset = (int) $offset;
	$isDark = (bool) $isDark;
	$isShifted = (bool) $isShifted;
	$colors = $palette->colors;
	$count = count( $colors );

	$output = '';

	foreach ( $colors as $index => $color ) {
		$oldColorIndex = ( $index + $offset ) % $count;

		if ( $isDark ) {
			if ( $oldColorIndex < $count / 2 ) {
				$oldColorIndex = 11 - $oldColorIndex;
			} else {
				continue;
			}
		}

		$output .= get_color_variables( $palette, $index, $oldColorIndex, $isShifted );
	}

	return $output;
}

/**
 * @since   2.0.0
 *
 * @param object $palette
 * @param int    $newColorIndex
 * @param int    $oldColorIndex
 * @param bool   $isShifted
 *
 * @return string
 */
function get_color_variables( $palette, $newColorIndex, $oldColorIndex, $isShifted ) {
	$newColorIndex = (int) $newColorIndex;
	$oldColorIndex = (int) $oldColorIndex;
	$isShifted = (bool) $isShifted;
	$colors = $palette->colors;
	$id = $palette->id;
	$count = count( $colors );
	$lightColorsCount = isset( $palette->lightColorsCount ) ? $palette->lightColorsCount : $count / 2;

	$accentColorIndex = ( $oldColorIndex + $count / 2 ) % $count;
	$prefix = '--sm-color-palette-';
	$suffix = $isShifted ? '-shifted' : '';

	$output = '';

	$output .= $prefix . $id . '-bg-color-' . ( $newColorIndex + 1 ) . $suffix . ': var(' . $prefix . $id . '-color-' . ( $oldColorIndex + 1 ) . ');' . PHP_EOL;
	$output .= $prefix . $id . '-accent-color-' . ( $newColorIndex + 1 ) . $suffix . ': var(' . $prefix . $id . '-color-' . ( $accentColorIndex + 1 ) . ');' . PHP_EOL;

	if ( $oldColorIndex < $lightColorsCount ) {
		$output .= $prefix . $id . '-fg1-color-' . ( $newColorIndex + 1 ) . $suffix . ': var(' . $prefix . $id . '-text-color-1);' . PHP_EOL;
		$output .= $prefix . $id . '-fg2-color-' . ( $newColorIndex + 1 ) . $suffix . ': var(' . $prefix . $id . '-text-color-2);' . PHP_EOL;
	} else {
		$output .= $prefix . $id . '-fg1-color-' . ( $newColorIndex + 1 ) . $suffix . ': var(' . $prefix . $id . '-color-1);' . PHP_EOL;
		$output .= $prefix . $id . '-fg2-color-' . ( $newColorIndex + 1 ) . $suffix . ': var(' . $prefix . $id . '-color-1);' . PHP_EOL;
	}

	return $output;
}

/**
 * @since   2.0.0
 *
 * @return array
 */
function get_fallback_palettes() {

	$order = array(
		"primary",
		"secondary",
		"tertiary",
		"quinary",
		"senary",
		"septenary",
		"octonary",
		"nonary",
		"denary"
	);

	$options_details = \Pixelgrade\StyleManager\get_option_details_all();

	$color_control_ids = array(
		'sm_color_primary',
		'sm_color_secondary',
		'sm_color_tertiary',
	);

	$lighter = get_fallback_color_value( 'sm_light_primary' );
	$light = get_fallback_color_value( 'sm_light_tertiary' );
	$text_color = get_fallback_color_value( 'sm_dark_secondary' );
	$dark = get_fallback_color_value( 'sm_dark_primary' );
	$darker = get_fallback_color_value( 'sm_dark_tertiary' );

	$palettes = array();

	foreach ( $color_control_ids as $index => $control_id ) {

		if ( empty( $options_details[ $control_id ] ) ) {
			continue;
		}

		$color = get_fallback_color_value( $control_id );

		$colors = array(
			$lighter,
			$light,
			$light,
			$light,
			$color,
			$color,
			$color,
			$dark,
			$dark,
			$dark,
			$darker,
			'#000000',
		);

		$color_objects = array();

		foreach ( $colors as $color ) {
			$obj = ( object ) array(
				'value' => $color
			);

			$color_objects[] = $obj;
		}

		$textColors = array(
			$text_color,
			$text_color,
		);

		$textColor_objects = array();

		foreach ( $textColors as $color ) {
			$obj = ( object ) array(
				'value' => $color
			);

			$textColor_objects[] = $obj;
		}

		$label = $order[ $index + 1 ];

		if ( $index === 0 ) {
			$label = __( 'Brand', 'style-manager' ) . ' ' . $label;
		} else {
			$label = ucfirst( $label );
		}

		$palettes[] = ( object ) array(
			'colors'      => $color_objects,
			'textColors'  => $textColor_objects,
			'source'      => $color,
			'sourceIndex' => 6,
			'label'       => $label,
			'id'          => $index + 1
		);
	}

	return $palettes;
}

function get_fallback_color_value( $id ) {

	$color = \Pixelgrade\StyleManager\get_option( $id . '_final' );

//	if ( empty( $color ) ) {
//		$color = PixCustomifyPlugin()->get_option( $id );
//	}
//
//	if ( empty( $color ) ) {
//		$config = PixCustomifyPlugin()->get_option_details( $id );
//
//		if ( isset( $config['default'] ) ) {
//			$color = $config['default'];
//		}
//	}

	return $color;
}

if ( ! function_exists( 'pixelgrade_option' ) ) {
	/**
	 * Get option value from the database
	 *
	 * @param string $option_id           The option name.
	 * @param mixed  $default             Optional. The default value to return when the option was not found or saved.
	 * @param bool   $force_given_default Optional. Ignored.
	 *
	 * @return mixed
	 */
	function pixelgrade_option( $option_id, $default = null, $force_given_default = false ) {
		return \Pixelgrade\StyleManager\get_option( $option_id, $default );
	}
}

if ( ! function_exists( 'sm_filter_user_palettes' ) ) {
	function sm_filter_user_palettes( $palette ) {
		$id = (string) $palette->id;
		return substr( $id, 0, 1 ) !== "_";
	}
}
